Frameless Window Widget (framelesswindow) — Orange Canvas Core 0.0.9 documentation

# Orange Canvas Core 0.0.9 documentation

## Frameless Window Widget (framelesswindow)

# Frameless Window Widget (`framelesswindow`)

A frameless window widget

class `orangecanvas.gui.framelesswindow.` `FramelessWindow`(parent=None, **kwargs)

  Bases: `PyQt5.QtWidgets.QWidget`

  A basic frameless window widget with rounded corners (if supported by the windowing system).

  `setRadius`(radius)

    Set the window rounded border radius.

  `radius`()

    Return the border radius.

  `radius_`

    Window border radius